pub fn mutate_all(payload: &str) -> Result<Vec<String>, EncodingError>Expand description
Combine all built-in mutations into a deduplicated set.
Errors
Returns EncodingError::UnknownTransform if an encoding name in the mix is not recognized.
pub fn mutate_all(payload: &str) -> Result<Vec<String>, EncodingError>Combine all built-in mutations into a deduplicated set.
Returns EncodingError::UnknownTransform if an encoding name in the mix is not recognized.