StaticPayloads

Struct StaticPayloads 

pub struct StaticPayloads { /* private fields */ }
A static payload source that holds payloads directly in memory.

This is useful for users who generate payloads externally and want to use them with the attackstr ecosystem.

Thread Safety

StaticPayloads is Send and Sync.

Example

use attackstr::{StaticPayloads, Payload, PayloadSource};

let payloads = vec![
    Payload {
        text: "test".into(),
        category: "custom".into(),
        technique: "manual".into(),
        context: "default".into(),
        encoding: "raw".into(),
        cwe: None,
        severity: None,
        confidence: 1.0,
        expected_pattern: None,
        target_media_type: None,
    },
];

let mut source = StaticPayloads::new(payloads);
assert_eq!(source.payloads("custom").len(), 1);

Implementations

Source

impl StaticPayloads

pub fn new(payloads: Vec<Payload>) -> Self

Create a new StaticPayloads from a vector of payloads.

Example:

use attackstr::{Payload, StaticPayloads};

let payloads = vec![Payload {
    text: "alert(1)".into(),
    category: "xss".into(),
    technique: "basic".into(),
    context: "default".into(),
    encoding: "raw".into(),
    cwe: None,
    severity: None,
    confidence: 1.0,
    expected_pattern: None,
    target_media_type: None,
}];

let source = StaticPayloads::new(payloads);
assert_eq!(source.all_payloads().len(), 1);
pub fn add(&mut self, payload: Payload)

Add a single payload to this source.

Example:

use attackstr::{Payload, StaticPayloads};

let mut source = StaticPayloads::default();
source.add(Payload {
    text: "test".into(),
    category: "custom".into(),
    technique: "manual".into(),
    context: "default".into(),
    encoding: "raw".into(),
    cwe: None,
    severity: None,
    confidence: 1.0,
    expected_pattern: None,
    target_media_type: None,
});
assert_eq!(source.all_payloads().len(), 1);
pub fn all_payloads(&self) -> &[Payload]

Get all payloads regardless of category.

Example:

use attackstr::StaticPayloads;

let source = StaticPayloads::default();
assert!(source.all_payloads().is_empty());
pub fn iter(&self) -> impl Iterator<Item = &Payload>

Iterate over all payloads in this source.

Example:

use attackstr::StaticPayloads;

let source = StaticPayloads::default();
assert_eq!(source.iter().count(), 0);
pub fn iter_category<'a>( &'a self, category: &'a str, ) -> impl Iterator<Item = &'a Payload> + 'a

Iterate over payloads for a single category.

Example:

use attackstr::{Payload, StaticPayloads};

let source = StaticPayloads::new(vec![Payload {
    text: "alert(1)".into(),
    category: "xss".into(),
    technique: "basic".into(),
    context: "default".into(),
    encoding: "raw".into(),
    cwe: None,
    severity: None,
    confidence: 1.0,
    expected_pattern: None,
    target_media_type: None,
}]);
assert_eq!(source.iter_category("xss").count(), 1);